pygwarts
========
Python multitool library

About
-----
This library is imbued with magic and built upon standard library only (no third party dependencies). It suggests various instruments, with fantastic semantic, to work with files, network, email and more. It also offers it's object model, that allows implementing additional instruments of any kinds.

Requirements
------------
``python`` >=3.10

Installation
------------
Get latest version from github
<br>``https://github.com/longdeer/pygwarts.git``
<br>
or from pip
<br>
``pip install pygwarts``

Then run ``tests/unit_main.py --clean-up`` to ensure capabilities.

Usage
-----
For guide please refer to the homepage.

Contribution
------------
There is a private development repository. If you want to contribute to ``pygwarts``, please contact me for invitation.
